@@ -19,7 +19,6 @@
 
 */
 
-#include <cstdlib>   // for std::exit
 #include <cstring>   // for std::strcmp
 #include <ctime>     // for std::time
 #include <exception> // for std::exception
@@ -37,7 +36,7 @@
 int main(int argc, char* argv[]) {
     if (argc != 2) {
         std::cerr << "Usage: " << argv[0] << " OUTFILE\n";
-        std::exit(1);
+        return 1;
     }
 
     // Get output file name from command line.
@@ -94,7 +93,7 @@ int main(int argc, char* argv[]) {
     } catch (const std::exception& e) {
         // All exceptions used by the Osmium library derive from std::exception.
         std::cerr << e.what() << '\n';
-        std::exit(1);
+        return 1;
     }
 }
 
