@@ -92,11 +92,11 @@ TEST_CASE("WKB geometry factory (byte-order-dependent): linestring with two same
     const auto& wnl = create_test_wnl_same_location(buffer);
 
     SECTION("unique forwards (default)") {
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::geometry_error);
     }
 
     SECTION("unique backwards") {
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), osmium::geometry_error);
     }
 
     SECTION("all forwards") {
@@ -116,7 +116,7 @@ TEST_CASE("WKB geometry factory (byte-order-dependent): linestring with undefine
 
     const auto& wnl = create_test_wnl_undefined_location(buffer);
 
-    REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::invalid_location&);
+    REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::invalid_location);
 }
 
 TEST_CASE("WKB geometry factory (byte-order-dependent): polygon") {
@@ -132,7 +132,7 @@ TEST_CASE("WKB geometry factory (byte-order-dependent): polygon") {
 
 TEST_CASE("WKB geometry (byte-order-independent) of empty point") {
     osmium::geom::WKBFactory<> factory{osmium::geom::wkb_type::wkb, osmium::geom::out_type::hex};
-    REQUIRE_THROWS_AS(factory.create_point(osmium::Location{}), const osmium::invalid_location&);
+    REQUIRE_THROWS_AS(factory.create_point(osmium::Location{}), osmium::invalid_location);
 }
 
 TEST_CASE("WKB geometry (byte-order-independent) of empty linestring") {
@@ -140,9 +140,9 @@ TEST_CASE("WKB geometry (byte-order-independent) of empty linestring") {
     osmium::memory::Buffer buffer{10000};
     const auto& wnl = create_test_wnl_empty(buffer);
 
-    REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::geometry_error&);
-    REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), const osmium::geometry_error&);
-    REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all), const osmium::geometry_error&);
-    REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward), const osmium::geometry_error&);
+    REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::geometry_error);
+    REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), osmium::geometry_error);
+    REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all), osmium::geometry_error);
+    REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward), osmium::geometry_error);
 }
 
