@@ -28,13 +28,13 @@ TEST_CASE("File based dense index") {
 
         REQUIRE(index.size() == 0);
 
-        REQUIRE_THROWS_AS(index.get(  0), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  1), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  3), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  5), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  6), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  7), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
+        REQUIRE_THROWS_AS(index.get(  0), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  1), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  3), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  5), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  6), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  7), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
 
         index.set(id1, loc1);
         REQUIRE(index.size() == 7);
@@ -47,11 +47,11 @@ TEST_CASE("File based dense index") {
         REQUIRE(loc1 == index.get(id1));
         REQUIRE(loc2 == index.get(id2));
 
-        REQUIRE_THROWS_AS(index.get(  0), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  1), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  5), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  7), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
+        REQUIRE_THROWS_AS(index.get(  0), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  1), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  5), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  7), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
 
         REQUIRE(index.size() == 7);
         REQUIRE(std::distance(index.cbegin(), index.cend()) == 7);
@@ -68,11 +68,11 @@ TEST_CASE("File based dense index") {
         REQUIRE(loc1 == index.get(id1));
         REQUIRE(loc2 == index.get(id2));
 
-        REQUIRE_THROWS_AS(index.get(  0), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  1), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  5), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  7), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
+        REQUIRE_THROWS_AS(index.get(  0), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  1), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  5), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  7), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
 
         REQUIRE(index.size() == 7);
         REQUIRE(std::distance(index.cbegin(), index.cend()) == 7);
@@ -107,13 +107,13 @@ TEST_CASE("File based sparse index") {
 
         REQUIRE(index.size() == 0);
 
-        REQUIRE_THROWS_AS(index.get(  0), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  1), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  3), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  5), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  6), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  7), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
+        REQUIRE_THROWS_AS(index.get(  0), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  1), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  3), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  5), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  6), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  7), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
 
         index.set(id1, loc1);
         REQUIRE(index.size() == 1);
@@ -126,11 +126,11 @@ TEST_CASE("File based sparse index") {
         REQUIRE(loc1 == index.get(id1));
         REQUIRE(loc2 == index.get(id2));
 
-        REQUIRE_THROWS_AS(index.get(  0), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  1), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  5), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  7), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
+        REQUIRE_THROWS_AS(index.get(  0), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  1), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  5), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  7), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
 
         REQUIRE(index.size() == 2);
         REQUIRE(std::distance(index.cbegin(), index.cend()) == 2);
@@ -147,11 +147,11 @@ TEST_CASE("File based sparse index") {
         REQUIRE(loc1 == index.get(id1));
         REQUIRE(loc2 == index.get(id2));
 
-        REQUIRE_THROWS_AS(index.get(  0), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  1), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  5), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(  7), const osmium::not_found&);
-        REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
+        REQUIRE_THROWS_AS(index.get(  0), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  1), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  5), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(  7), osmium::not_found);
+        REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
 
         REQUIRE(index.size() == 2);
         REQUIRE(std::distance(index.cbegin(), index.cend()) == 2);
