@@ -4,12 +4,14 @@
 #include <osmium/io/writer.hpp>
 #include <osmium/io/xml_output.hpp>
 
-TEST_CASE("Output iterator should be copy constructable") {
+TEST_CASE("Output iterator should be copy constructable and incrementable") {
     const osmium::io::Header header{};
     osmium::io::Writer writer{"test.osm", header, osmium::io::overwrite::allow};
 
     osmium::io::OutputIterator<osmium::io::Writer> out1{writer};
     osmium::io::OutputIterator<osmium::io::Writer> out2{out1};
+
+    ++out2;
 }
 
 TEST_CASE("Output iterator should be copy assignable") {
@@ -23,11 +25,3 @@ TEST_CASE("Output iterator should be copy assignable") {
     out2 = out1;
 }
 
-TEST_CASE("Output iterator should be incrementable") {
-    const osmium::io::Header header{};
-    osmium::io::Writer writer{"test.osm", header, osmium::io::overwrite::allow};
-    osmium::io::OutputIterator<osmium::io::Writer> out{writer};
-
-    ++out;
-}
-
